polyfemos.scripts.devserver — polyfemos 0.3.29 documentation

# polyfemos.scripts.devserver

A command line script to create polyfemos development server, call the script in folder where ‘conf/front/global_config.yml’ is available.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.scripts.devserver.` `main`(argv=None)
  Parameters

    argv (list) – command line arguments